# see https://ipython.org/ipython-doc/3/config/custommagics.html
# for more details on the implementation here
import json
import uuid

from IPython.core.getipython import get_ipython
from IPython.core.magic import Magics, magics_class, cell_magic
from IPython.display import display, Javascript
from pkg_resources import resource_filename


@magics_class
class JupyterNotifyMagics(Magics):
    def __init__(self, shell, require_interaction=False):
        super(JupyterNotifyMagics, self).__init__(shell)
        with open(resource_filename("jupyternotify", "js/init.js")) as jsFile:
            jsString = jsFile.read()
        display(Javascript(jsString))
        self.options = json.dumps({
            "requireInteraction": require_interaction,
            "body": "Cell Execution Has Finished!!",
            "icon": "/static/base/images/favicon.ico",
        })

    @cell_magic
    def notify(self, line, cell):
        # generate a uuid so that we only deliver this notification once, not again
        # when the browser reloads (we append a div to check that)
        notification_uuid = uuid.uuid4()

        output = get_ipython().run_cell(cell)

        # display our browser notification using javascript
        with open(resource_filename("jupyternotify", "js/notify.js")) as jsFile:
            jsString = jsFile.read()
        display(Javascript(jsString % {
            "notification_uuid": notification_uuid,
            "options": self.options,
        }))

        # finally, if we generated an exception, print the traceback
        if output.error_in_exec is not None:
            output.raise_error()



# -*- coding: utf-8 -*-

from setuptools import find_packages, setup

with open('README.rst') as r:
    readme = r.read()

with open('AUTHORS.txt') as a:
    # reSt-ify the authors list
    authors = ''
    for author in a.read().split('\n'):
        authors += '| '+author+'\n'

with open('LICENSE.txt') as l:
    license = l.read()

setup(
    name='jupyternotify',
    version='0.1.9',
    description='A Jupyter Notebook %%magic for Browser Notifications of Cell Completion',
    long_description=readme+'\n\n'+authors+'\nLicense\n-------\n'+license,
    author='Michelangelo D\'Agostino',
    author_email='mdagostino@shoprunner.com',
    url='https://github.com/shoprunner/jupyter-notify',
    license='BSD-3-Clause',
    packages=find_packages(exclude=('tests', 'docs')),
    package_data={'jupyternotify': ['js/*.js']},
    install_requires=[
        'ipython',
        'jupyter'
    ]
)
